# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_member_packages_out import WrappedResponseMemberPackagesOut  # noqa: E501

class TestWrappedResponseMemberPackagesOut(unittest.TestCase):
    """WrappedResponseMemberPackagesOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseMemberPackagesOut:
        """Test WrappedResponseMemberPackagesOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseMemberPackagesOut`
        """
        model = WrappedResponseMemberPackagesOut()  # noqa: E501
        if include_optional:
            return WrappedResponseMemberPackagesOut(
                done = True,
                result = access_server_connector.models.member_packages_out.MemberPackagesOut(
                    count = 56, 
                    items = [
                        access_server_connector.models.owned_package_out.OwnedPackageOut(
                            access_package_id = 56, 
                            title = '', 
                            payment_type = '', 
                            is_active = True, 
                            is_locked = True, 
                            reason_id = 56, 
                            kind = 'order', 
                            status = 'active', 
                            granted_at = 56, )
                        ], )
            )
        else:
            return WrappedResponseMemberPackagesOut(
                result = access_server_connector.models.member_packages_out.MemberPackagesOut(
                    count = 56, 
                    items = [
                        access_server_connector.models.owned_package_out.OwnedPackageOut(
                            access_package_id = 56, 
                            title = '', 
                            payment_type = '', 
                            is_active = True, 
                            is_locked = True, 
                            reason_id = 56, 
                            kind = 'order', 
                            status = 'active', 
                            granted_at = 56, )
                        ], ),
        )
        """

    def testWrappedResponseMemberPackagesOut(self):
        """Test WrappedResponseMemberPackagesOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
